@@ -583,7 +583,7 @@ g_resources_unregister_unlocked (GResource *resource)
 {
   if (g_list_find (registered_resources, resource) == NULL)
     {
-      g_warning ("Tried to remove not registred resource");
+      g_warning ("Tried to remove not registered resource");
     }
   else
     {
@@ -633,7 +633,7 @@ g_resources_unregister (GResource *resource)
  * @error: return location for a #GError, or %NULL
  *
  * Looks for a file at the specified @path in the set of
- * globally registred resources and returns a #GInputStream
+ * globally registered resources and returns a #GInputStream
  * that lets you read the data.
  *
  * @lookup_flags controls the behaviour of the lookup.
@@ -693,7 +693,7 @@ g_resources_open_stream (const gchar           *path,
  * @error: return location for a #GError, or %NULL
  *
  * Looks for a file at the specified @path in the set of
- * globally registred resources and returns a #GBytes that
+ * globally registered resources and returns a #GBytes that
  * lets you directly access the data in memory.
  *
  * The data is always followed by a zero byte, so you
@@ -762,7 +762,7 @@ g_resources_lookup_data (const gchar           *path,
  * @error: return location for a #GError, or %NULL
  *
  * Returns all the names of children at the specified @path in the set of
- * globally registred resources.
+ * globally registered resources.
  * The return result is a %NULL terminated list of strings which should
  * be released with g_strfreev().
  *
@@ -843,7 +843,7 @@ g_resources_enumerate_children (const gchar           *path,
  * @error: return location for a #GError, or %NULL
  *
  * Looks for a file at the specified @path in the set of
- * globally registred resources and if found returns information about it.
+ * globally registered resources and if found returns information about it.
  *
  * @lookup_flags controls the behaviour of the lookup.
  *
@@ -1013,7 +1013,7 @@ g_static_resource_fini (GStaticResource *static_resource)
  * g_static_resource_get_resource:
  * @static_resource: pointer to a static #GStaticResource
  *
- * Gets the GResource that was registred by a call to g_static_resource_init().
+ * Gets the GResource that was registered by a call to g_static_resource_init().
  *
  * This is normally used by code generated by
  * <link linkend="glib-compile-resources">glib-compile-resources</link>
