@@ -35,9 +35,9 @@
  * @see_also: #GTlsConnection
  *
  * A certificate used for TLS authentication and encryption.
- * This can represent either a public key only (eg, the certificate
+ * This can represent either a certificate only (eg, the certificate
  * received by a client from a server), or the combination of
- * a public key and a private key (which is needed when acting as a
+ * a certificate and a private key (which is needed when acting as a
  * #GTlsServerConnection).
  *
  * Since: 2.28
@@ -58,8 +58,10 @@ enum
   PROP_0,
 
   PROP_CERTIFICATE,
+  PROP_CERTIFICATE_BYTES,
   PROP_CERTIFICATE_PEM,
   PROP_PRIVATE_KEY,
+  PROP_PRIVATE_KEY_BYTES,
   PROP_PRIVATE_KEY_PEM,
   PROP_ISSUER
 };
@@ -98,10 +100,10 @@ g_tls_certificate_class_init (GTlsCertificateClass *class)
   /**
    * GTlsCertificate:certificate:
    *
-   * The DER (binary) encoded representation of the certificate's
-   * public key. This property and the
-   * #GTlsCertificate:certificate-pem property represent the same
-   * data, just in different forms.
+   * The DER (binary) encoded representation of the certificate.
+   * This property and the #GTlsCertificate:certificate-bytes contain
+   * the same data. The #GTlsCertificate:certificate-pem property
+   * represents the same data, just in different forms.
    *
    * Since: 2.28
    */
@@ -113,12 +115,30 @@ g_tls_certificate_class_init (GTlsCertificateClass *class)
 						       G_PARAM_READWRITE |
 						       G_PARAM_CONSTRUCT_ONLY |
 						       G_PARAM_STATIC_STRINGS));
+  /**
+   * GTlsCertificate:certificate-bytes:
+   *
+   * The DER (binary) encoded representation of the certificate as
+   * a #GBytes. The #GTlsCertificate:certificate property contains
+   * the same data. The #GTlsCertificate:certificate-pem property
+   * contains the same data as this property in a different form.
+   *
+   * Since: 2.34
+   */
+  g_object_class_install_property (gobject_class, PROP_CERTIFICATE_BYTES,
+                                   g_param_spec_boxed ("certificate-bytes",
+                                                       P_("Certificate Bytes"),
+                                                       P_("The DER representation of the certificate"),
+                                                       G_TYPE_BYTES,
+                                                       G_PARAM_READWRITE |
+                                                       G_PARAM_CONSTRUCT_ONLY |
+                                                       G_PARAM_STATIC_STRINGS));
   /**
    * GTlsCertificate:certificate-pem:
    *
-   * The PEM (ASCII) encoded representation of the certificate's
-   * public key. This property and the #GTlsCertificate:certificate
-   * property represent the same data, just in different forms.
+   * The PEM (ASCII) encoded representation of the certificate.
+   * The #GTlsCertificate:certificate and #GTlsCertificate:certificate-bytes
+   * properties represent the same data, just in a different form.
    *
    * Since: 2.28
    */
@@ -153,6 +173,23 @@ g_tls_certificate_class_init (GTlsCertificateClass *class)
 						       G_PARAM_WRITABLE |
 						       G_PARAM_CONSTRUCT_ONLY |
 						       G_PARAM_STATIC_STRINGS));
+  /**
+   * GTlsCertificate:private-key-bytes:
+   *
+   * The DER (binary) encoded representation of the certificate's
+   * private key. This property and the #GtlsCertificate:private-key
+   * property contain the same data.
+   *
+   * Since: 2.34
+   */
+  g_object_class_install_property (gobject_class, PROP_PRIVATE_KEY_BYTES,
+                                   g_param_spec_boxed ("private-key-bytes",
+                                                       P_("Private key bytes"),
+                                                       P_("The DER representation of the certificate's private key"),
+                                                       G_TYPE_BYTES,
+                                                       G_PARAM_WRITABLE |
+                                                       G_PARAM_CONSTRUCT_ONLY |
+                                                       G_PARAM_STATIC_STRINGS));
   /**
    * GTlsCertificate:private-key-pem:
    *
@@ -560,3 +597,39 @@ g_tls_certificate_verify (GTlsCertificate     *cert,
 {
   return G_TLS_CERTIFICATE_GET_CLASS (cert)->verify (cert, identity, trusted_ca);
 }
+
+/**
+ * g_tls_certificate_is_same:
+ * @cert_one: first certificate to compare
+ * @cert_two: second certificate to compare
+ *
+ * Check if two #GTlsCertificate objects represent the same certificate.
+ * The raw DER byte data of the two certificates are checked for equality.
+ * This has the effect that two certificates may compare equal even if
+ * their #GTlsCertificate:issuer, #GTlsCertificate:private-key, or
+ * #GTlsCertificate:private-key-pem properties differ.
+ *
+ * Return value: whether the same or not
+ *
+ * Since: 2.34
+ */
+gboolean
+g_tls_certificate_is_same (GTlsCertificate     *cert_one,
+                           GTlsCertificate     *cert_two)
+{
+  GBytes *b1, *b2;
+  gboolean equal;
+
+  g_return_val_if_fail (G_IS_TLS_CERTIFICATE (cert_one), FALSE);
+  g_return_val_if_fail (G_IS_TLS_CERTIFICATE (cert_two), FALSE);
+
+  g_object_get (cert_one, "certificate-bytes", &b1, NULL);
+  g_object_get (cert_two, "certificate-bytes", &b2, NULL);
+
+  equal = g_bytes_equal (b1, b2);
+
+  g_bytes_unref (b1);
+  g_bytes_unref (b2);
+
+  return equal;
+}
