@@ -25,9 +25,6 @@
 #include <string.h>
 
 #include <sys/types.h>
-#ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif
 
 #include "gdbus-tests.h"
 
@@ -97,10 +94,8 @@ test_connection_flush (void)
                                        &exit_status,
                                        &error);
       g_assert_no_error (error);
-#ifdef HAVE_SYS_WAIT_H
-      g_assert (WIFEXITED (exit_status));
-      g_assert_cmpint (WEXITSTATUS (exit_status), ==, 0);
-#endif
+      g_spawn_check_exit_status (exit_status, &error);
+      g_assert_no_error (error);
       g_assert (ret);
 
       timeout_mainloop_id = g_timeout_add (1000, test_connection_flush_on_timeout, GUINT_TO_POINTER (n));
